/**
 * @file Ce fichier genere le shema utilise par Apollo. C'est ici que les requetes GraphQl sont résolues.
 * @author akka vodol
*/

import knex from '../../db/knex_router';
import { listGroups, listMembers } from '../ldap/ldap_data';
import { makeExecutableSchema } from 'graphql-tools';
import { request } from 'https';

const typeDefs = `
    type Query {
        allGroups: [Group]
        group(uid: ID) : Group
    }

    type Group {
        name: String
        uid: ID
        website: String
        updatedAt: String
        description: String
        school: String
    }
`;

const getAllVisibleGroups = (user) => {

    var group_ids =   listGroups(user.id).then(res => {
        console.log(res.concat(['kes']));
        return res.concat(['kes']);
    });
    var membered_groups = qb => qb.select().from('groups').whereIn('uid', ['faerix', 'data']);
    return knex.with('membered_groups', membered_groups).distinct('groups.*').select().from('groups').innerJoin('membered_groups', 
        function() {
            this.on('groups.uid', '=', 'membered_groups.uid').orOn('groups.parentuid', '=', 'membered_groups.uid');
        }
    );
};
    
const getGroupIfVisible = (user, uid) => {
    return getAllVisibleGroups(user).where('groups.uid', uid).then(res => {
        return res[0];
    });
};

const resolvers = {
    Query: {
        allGroups: (obj, args, context) => {
            return getAllVisibleGroups(context.user);
        },
        group: (obj, args, context) => {
            return getGroupIfVisible(context.user, args.uid);
        }
    }
};

const schema = makeExecutableSchema({
    typeDefs,
    resolvers
});

export default schema;